# noinspection PyPep8Naming
import datetime as dt

import attr

from .enums import HorizontalOrigins, InterpolationAlgorithms, VerticalOrigins


@attr.s(repr=False, frozen=True, kw_only=True)
class Deletable:
    """A property whose value may be deleted."""

    delete: bool = attr.ib(default=None)


# noinspection PyPep8Naming
@attr.s(repr=False, frozen=True, kw_only=True)
class Interpolatable:
    """A property whose value may be determined by interpolating.

    The interpolation happens over provided time-tagged samples.
    """

    epoch: dt.datetime = attr.ib(default=None)
    interpolationAlgorithm: InterpolationAlgorithms = attr.ib(default=None)
    interpolationDegree: int = attr.ib(default=None)


# noinspection PyPep8Naming
@attr.s(repr=False, frozen=True, kw_only=True)
class HasAlignment:
    """A property that can be horizontally or vertically aligned."""

    horizontalOrigin: HorizontalOrigins = attr.ib(default=None)
    verticalOrigin: VerticalOrigins = attr.ib(default=None)



from .properties import Color


def get_color(color):
    # Color.from_string, Color.from_int, ...
    if isinstance(color, str) and 6 <= len(color) <= 10:
        return Color.from_str(color)
    elif isinstance(color, int):
        return Color.from_hex(color)
    elif isinstance(color, list) and len(color) <= 4:
        return Color.from_list(color)
    else:
        raise ValueError("Invalid input")



from ._version import get_versions
from .core import CZML_VERSION, Document, Packet, Preamble

__version__ = get_versions()["version"]
del get_versions

__all__ = ["Document", "Preamble", "Packet", "CZML_VERSION"]
